#
# spec file for package gnome-latex
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-latex
Version:        3.46.0
Release:        1.2
Summary:        Integrated LaTeX Environment for the GNOME desktop
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://wiki.gnome.org/Apps/GNOME-LaTeX
Source0:        https://download.gnome.org/sources/%{name}/3.46/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  gsettings-desktop-schemas-devel
BuildRequires:  gtk-doc
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.34
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(gee-0.8) >= 0.10
BuildRequires:  pkgconfig(gio-2.0) >= 2.56
BuildRequires:  pkgconfig(glib-2.0) >= 2.56
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(gspell-1) >= 1.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gtksourceview-4) >= 3.99.7
BuildRequires:  pkgconfig(libgedit-amtk-5)
BuildRequires:  pkgconfig(tepl-6) >= 6.4
BuildRequires:  pkgconfig(vapigen) >= 0.34
Requires:       gsettings-desktop-schemas
Requires:       texlive-latexmk-bin
Provides:       latexila = %{version}
Obsoletes:      latexila < %{version}

%description
Gnome-latex is an Integrated LaTeX Environment for GNOME. The main
features are:
  * Configurable buttons to compile, convert and view a document in
    one click.
  * LaTeX commands auto-completion.
  * Symbol tables (Greek letters, arrows, ...).
  * File browser integrated.
  * Template managing.
  * Menus with the most commonly used LaTeX commands.
  * Easy projects management.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
	--enable-gtk-doc \
	%{nil}
%make_build

%install
%make_install
%find_lang %{name}
%fdupes -s %{buildroot}%{_datadir}

%files -f %{name}.lang
%license COPYING
%doc AUTHORS README NEWS HACKING
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/*/
%{_datadir}/applications/*
%{_datadir}/dbus-1/services/org.gnome.%{name}.service
%{_datadir}/glib-2.0/schemas/org.gnome.%{name}.gschema.xml
%{_datadir}/metainfo/org.gnome.%{name}.appdata.xml
%{_mandir}/man1/%{name}.1%{?ext_man}
%dir %{_datadir}/gtk-doc/html
%dir %{_datadir}/gtk-doc/html/%{name}
%doc %{_datadir}/gtk-doc/html/%{name}

%changelog
* Mon Aug 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.46.0:
  + Port to latest Tepl API.
  + Adapt for Amtk -> libgedit-amtk rename.
- Replace pkgconfig(amtk-5) with pkgconfig(libgedit-amtk-5)
  BuildRequires following upstream changes.
* Thu Jan  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.44.0:
  + Use more Tepl features.
  + Adapt to Tepl API breaks.
* Fri Nov  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.42.0:
  + A few minor improvements.
- Changes from version 3.41.2:
  + User-visible changes:
  - Preferences dialog:
    . Some changes in the presentation of the options (still the
    same set of options).
    . Better i18n/l10n support by avoiding splitting sentences
    with a spin-button in-between (for example to choose the
    number of minutes for the auto-save interval).
  - PostProcessorLatexmk: parse xelatex output within latexmk.
  + Under the hood changes:
  - Construct the Preferences dialog differently, by moving some
    functionality to Tepl, without using a *.ui file, and do a
    maximum in C (not Vala). More work in that area would be
    possible, but it was done incrementally (in a releasable state
    all the time).
  + For packagers: A precise version of Tepl is required because
    Tepl API stability is no longer guaranteed.
- Changes 3.41.1:
  + User-visible changes:
  - Build Tools preferences dialog: add a note about restarting
    the application.
  - Minor bug fix to directly update the GUI if the system fixed
    width font is modified.
  + Under the hood changes:
  - Continue to move more features (and improve them) to the Amtk
    and Tepl libraries.
  - Simplify / refresh some parts of the code.
  + Build system: many improvements and simplifications.
  + For the Vala code, use the *.gir file of GtkSourceView (instead
    of the *.vapi file). And no longer generate latexila.vapi for
    the internal library.
  + Migrate from Intltool to pure gettext.
  + But the *.desktop file and AppData are no longer translated,
    need to find a better solution.
  + Better support MSYS2/MINGW (Windows), normally no patches are
    required anymore:
  - liblatexila: add latexila_dirs functions, inspired by
    gedit_dirs.
  - Other small tweak.
  + Documentation: many improvements to the contributors' docs.
  + Other small improvements here and there.
- Changes from version  3.40.0:
  + Documentation improvement.
- Changes from version 3.39.1:
  + The project is now hosted at:
    https://gitlab.gnome.org/swilmet/gnome-latex
  + Port to the development version of Tepl 6.
  + Build system update.
  + Have everything in git repositories, no longer use the GNOME
    wiki.
  + Updated translations.
- Add explicit pkgconfig(amtk-5) BuildRequires following upstreams
  changes.
- Drop e1b01186f8a.patch: Fixed upstream.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Apr 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Port to tepl-6:
  + Add e1b01186f8a.patch: actual port, patch from upstream.
  + Add call to autoreconf in build phase, as above patch touches
    the build system.
* Fri Sep 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.0:
  + Updated translations.
* Mon Sep  7 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.37.2:
  + User-visible changes:
  - New application icon.
  - Use Tepl for the 'go to line' feature.
  - Create the Edit toolbar with Amtk. This fixes the problem
    with some buttons doing nothing when clicked (for the buttons
    containing a secondary arrow button that displays a menu; now
    the two buttons are merged).
  + Under the hood changes:
  - The LaTeX and Math menus are now created with Amtk, not with
    GtkUIManager.
  - Rewrite some code in C in the liblatexila, to have less Vala
    code.
  - App icon: rename to org.gnome.gnome-latex.
- Changes from version 3.37.1:
  + User-visible changes:
  - Use TeplPanel to create the side panel. This changes the UI
    for switching between side panel components, it's now like a
    toolbar (so only a single click is needed), before it was
    with a GtkComboBox list (so with two clicks).
  - Search and Go to line: better style for the text entry's
    not-found state.
  - More beautiful close buttons at some places.
  - Use some Tepl I/O error info bars.
  + Under the hood changes:
  - Port to TeplMetadata.
  - Use TeplStatusbar.
  - Use TeplStyleSchemeChooserWidget in the preferences dialog.
  - Subclass TeplAbstractFactory, not TeplAbstractFactoryVala.
  - Move more utility functions to Tepl.
  - Remove some dead code.
  - Remove no longer useful code related to stock icons.
  - New classes in the liblatexila (so in C): LatexilaFactory,
    LatexilaSettings.
  + Updated translations.
- Replace pkgconfig(tepl-4) BuildRequires with pkgconfig(tepl-5):
  follow upstream changes.
* Wed Apr  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Fix compilation error with valac >= 0.42.
  + Move some utils functions to Tepl.
  + Build system: small update.
  + AppData: small update.
  + Updated translations.
* Sun Mar 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Apply GNOME goal “App menu retirement”.
  + New icon for GNOME LaTeX.
  + Updated translations.
* Sun Aug  5 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Close crowdfunding.
* Thu Jul 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Come back to valac 0.40, more crashes have been discovered when
    gnome-latex is compiled with valac git master (what will become
    valac 0.42).
  + Updated translations.
* Mon Jul 23 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Change go-to-line shortcut from Ctrl+G to Ctrl+L.
  + Adapt some Vala code to make it work with valac >= 0.42.
  + Updated translations.
* Mon May 21 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + New configure build option: --disable-dconf-migration, intended
    to be used only on OSes where dconf cannot be installed.
  + Updated translations.
* Sun Apr  8 2018 bjorn.lie@gmail.com
- Update to version 3.28.0:
  + Under the hood changes:
  - Project moved to GNOME GitLab.
  - Apply GtkSourceView coding style to *.c files.
  - Reduce delta between Vala and C coding styles.
  - Improve documentation for contributors.
  - Finish to port the Math menu to GAction
  + User-visible changes:
  - On first launch of GNOME LaTeX, import LaTeXila settings and
    user data/config files.
  - Change Find and Replace shortcut to Ctrl+H, to be like in
    gedit.
  - Update/improve the user documentation for the spell-checking.
  - Updated translations.
- Add pkgconfig(dconf) BuildRequires, new dependency.
- Enable translation-update-upstream unconditionally.
* Mon Mar 12 2018 bjorn.lie@gmail.com
- Update to version 3.27.2:
  + Rename LaTeXila to GNOME LaTeX.
  + Some code maintenance (do not use some deprecated GTK+
    functions).
  + Updated translations.
- Rename to gnome-latex following upstreams name rename.
- Drop gnome-desktop BuildRequires, not needed, nor used.
- Drop update-desktop-files BuildRequires and no longer run
  suse_update_desktop_file macro, no longer needed.
- Add latexila Provides/Obsoletes, ensure smooth upgrades.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Dec  9 2017 luc14n0@linuxmail.org
- Update to version 3.27.1:
  + User-visible improvements:
  - Draw non-breaking spaces.
  - File browser in the side panel: popup menus under buttons.
  + Port to GtkSourceView 4 and Tepl 4.
  + Internal code refactorings, use more Tepl features:
  - Use more Tepl GActions.
  - Let Tepl handle the window title.
  - Implement TeplAbstractFactoryVala subclass.
  - Other small things.
  + Port to GAction/Amtk:
  - Port the whole LaTeX menu to GAction and C in the
    liblatexila.
  - Math menu in progress.
  - Create first AmtkActionInfo.
  + Updated translations.
- Switch gtksourceview-3.0 and tepl-3 pkgconfig BuildRequires
  modules by gtksourceview-4 and tepl-4, following upstream change.
- Adopt the use of %%make_build macro instead of raw make command,
  following best practices.
- Pass missing enable-gtk-doc to configure once the development
  documentation is desired.
* Wed Nov  1 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Updated translations.
- Drop %%glib2_gsettings_schema_*, %%desktop_database_* and
  %%icon_theme_cache_* post/postun/requires macros: functionality
  now covered by file triggers.
- Conditionalize the use of translation-update-upstream: sle-only
  requirement.
- Align with configure:
  + Drop gettext-tools BuildRequires.
  + Add gtk-doc and pkgconfig(glib-2.0) BuildRequires.
* Sat Oct 28 2017 jengelh@inai.de
- Use standardized %%configure call.
* Thu Sep 14 2017 fezhang@suse.com
- Drop SLE12 / Leap42 conditional, %%{_datadir}/appdata is now owned
  by the filesystem package.
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Internal code refactoring, use more Tepl features.
  + latexmk post-processor: fix bug with LaTeX errors and warnings
    not detected with new versions of latexmk.
  + Small improvement: make the tab label tooltip clearer:
    "Main file" -> "Project main file".
  + Small bug fixes:
  - Search: replace all button: center content vertically.
  - LaTeX and Math menus: grab focus to active text view after
    inserting text.
  + Updated translations.
* Wed Aug 23 2017 dimstar@opensuse.org
- Update to version 3.25.1:
  + The Gtef library has been renamed to Tepl, adapt the code
    accordingly.
  + Use more Tepl features.
  + Code maintenance to not use a deprecated GTK+ function.
  + Updated translations.
- Replace pkgconfig(gtef-2) BuildRequires with pkgconfig(tepl-3),
  following upstreams port.
* Sun Aug 20 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + latexmk post-processor: fix bug with LaTeX errors and warnings
    not detected with new versions of latexmk.
  + Small bug fixes:
  - Search: replace all button: center content vertically.
  - LaTeX and Math menus: grab focus to active text view after
    inserting text.
* Sun Jun 25 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Fix a crash when moving a tab to a new window (regression in
    3.24).
* Sun Jun 11 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Create app menu only if the desktop prefers one, to avoid a
    double menubar on e.g. Xfce.
  + Other small code improvements.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Sun Mar 12 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Easier keyboard shortcuts for bold, italic and underline:
    <Control>B/I/U.
  + In the menus to open a recently used file, show a tooltip with
    the full path.
  + Document structure: fix bug to allow "TODO: ..." and
    "FIXME: ..." (with the colon).
  + Other small code improvements.
  + Fix minor issues found by Coverity.
  + Updated translations.
* Sat Jan 28 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + Update code to not use deprecated GtkSourceView APIs.
  + Use the Gtef library; Some functionality has been moved from
    LaTeXila to Gtef.
  + Change menu item label "Search Forward" -> "Jump to PDF" to not
    confuse it with the normal search and replace feature. And
    adapt the docs accordingly.
  + Update the build system to use autoconf-archive macros instead
    of gnome-common.
  + Updated translations.
- Add pkgconfig(gtef-2) BuildRequires: new dependency.
* Sun Dec 18 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Fix Vala compilation error with newer valac compiler.
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Fundraising.
  + Update AppData.
  + Updated translations.
* Fri Jul 29 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Bug fix: initialize correctly the build view settings (to hide
    warnings/badboxes).
  + Updated translations.
* Sun Mar 20 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Mon Mar 14 2016 zaitor@opensuse.org
- Update to version 3.19.5:
  + Adapt code for gspell API changes.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.4:
  + Close fundraiser.
  + Adapt code for gspell API changes.
  + AppData: add translation tag.
  + Updated translations.
* Wed Jan 27 2016 zaitor@opensuse.org
- Update to version 3.19.3:
  + Adapt code for gspell API changes.
  + Adapt code to support again loading and saving remote files.
  + Better gnome-shell integration: add an application menu and fix
    the "Open a New Window" right-click action.
  + Make LaTeXila D-Bus activatable.
  + Change "Unsaved Document" to "Untitled Document".
  + Other various small code improvements.
  + Updated translations.
* Sat Dec 19 2015 badshah400@gmail.com
- Update to version 3.19.2:
  + Adapt code for GspellLanguage API changes.
  + Adapt CSS to track GTK+ changes.
  + Rename latexila.deskop to org.gnome.latexila.desktop.
  + Rename AppData to org.gnome.latexila.appdata.xml.
  + Other various small improvements and bug fixes.
- Update file list to reflect change of file names:
  + Desktop menu entry got renamed to org.gnome.latexila.desktop.
  + Appdata file got renamed to org.gnome.latexila.appdata.xml.
- Changes from version 3.19.1:
  + Adapt code for GspellLanguageChooserDialog change.
* Sat Dec 19 2015 badshah400@gmail.com
- Update to version 3.18.2:
  + AppData: add kudos.
  + Fix a syntax error in desktop file keywords German
    translation.
  + Adapt code to support again remote files.
* Fri Nov 13 2015 badshah400@gmail.com
- Update to version 3.18.1:
  - Fix regressions from gtk+ changes during the 3.18 cycle.
  - Updated translations.
- Changes from version 3.18.0:
  - Use gspell instead of GtkSpell.
  - Add default spell checking settings in the preferences dialog.
  - Via the Tools menu, the spell checking settings can be changed
    and are stored on a file-by-file basis.
  - There is now a spell checker dialog window, to spell check an
    entire file word-by-word.
  - Ensure that the personal build tools and the templates are
    correctly saved.
  - Other various small improvements and bug fixes.
  - Translation updates.
- Update BuildRequires:
  + Add pkgconfig(gspell-1)
  + Add pkgconfig(gobject-introspection-1.0)
  + Add pkgconfig(vapigen)
  + Update required versions
  + Remove pkgconfig(gtkspell3-3.0).
- Remove runtime dependency on rubber (no longer used for
  latexila's build tools), add texlive-latexmk-bin instead.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Ensure that the personal build tools are correctly saved.
  + A few other small bug fixes.
  + Updated translations.
* Sat Aug 15 2015 badshah400@gmail.com
- For openSUSE:42, have package own the /usr/share/appdata dir;
  fixes build failure.
* Sun Apr 19 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Fix the build with -Werror=format-security.
  + Important bug fix when deleting several templates at once.
* Wed Mar 25 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Various small improvements.
  + Updated translations.
* Wed Mar 25 2015 zaitor@opensuse.org
- Update to version 3.14.4:
  + Show information about LaTeXila fundraiser.
  + Various bug fixes.
  + Updated translations.
* Wed Jan  7 2015 zaitor@opensuse.org
- Update to version 3.14.3:
  + Adapt code for GtkSourceView 3.14.3.
  + Updated translations.
* Mon Nov  3 2014 badshah400@gmail.com
- Update to version 3.14.2:
  + Build: a file was missing in tarballs
  + Add keywords to latexila.desktop
  + Translation updates.
* Wed Oct  1 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + A few bug fixes and small improvements.
  + GTK+ 3.14 is required because LaTeXila overrides some CSS
    properties and assumes that GTK+ 3.14 is used.
- Drop conditional pkgconfig(gtkspell-3.0) and xz BuildRequires for
  older version of openSUSE, as latexila now has a hard BuildReq on
  pkgconfig(gtk+-3.0) >= 3.14.0.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Now LaTeXila follows the GNOME versions.
  + Better icons.
  + Upgrade to gee-0.8.
  + Other small improvements.
- Changes from version 3.12.1:
  + Fix regex in latex post-processor.
  + GLib 2.40 is required
  + Updated translations.
- Changes from version 3.12.0:
  + Refresh structure when saving.
  + Misc bugfixes and small improvements.
  + Updated translations.
- Changes from version 2.10.0:
  + Updated translations.
- Changes from version 2.9.0:
  + Search and replace: use the new API from GtkSourceView.
  + Use upstream GtkSpell (LaTeXila depends on GtkSpell now,
    instead of Enchant).
  + Improvements to the completion.
  + AppData file.
  + Updated translations.
- Drop obsolete pkgconfig(enchant) BuildRequires, no longer needed.
- Replace pkgconfig(gee-1.0) for pkgconfig(gee-0.8) BuildRequires,
  following upstream changes.
- Add pkgconfig(gio-2.0) BuildRequires: New dependency.
* Thu Sep 19 2013 badshah400@gmail.com
- Update to version 2.8.3:
  + Build tools: fix crash on unknown post processor
  + Updated Galician translations
- Drop latexila-fix-makefile.patch; properly fixed upstream
- Drop latexila-do-not-disable-deprecated-apis.patch; patch
  implemented upstream. Also drop autotool build requirements due
  to this patch.
* Thu Aug 29 2013 badshah400@gmail.com
- Fix source URL.
* Mon Aug 26 2013 badshah400@gmail.com
- Update to version 2.8.2:
  + Misc bugfixes
- Add latexila-do-not-disable-deprecated-apis.patch to enable
  usage of deprecated symbols in gtk3-3.9.10; this fixes build
  failures in Factory; patch taken from upstream git.
- Add latexila-fix-makefile.patch to fix trivial issue in a
  makefile which caused build errors.
* Tue May  7 2013 badshah400@gmail.com
- Update to version 2.8.1:
  + Bump required version of GLib to 2.36
  + Add Catalan and Greek translations
  + Translations updates
  + Misc bugfixes
- Drop patch
  latexila-replace-deprecated-gtk_widget_render_icon.patch;
  implemented upstream.
* Sun May  5 2013 badshah400@gmail.com
- Update to version 2.8.0:
  + Allow the menu bar to shrink below its minimum size
  + Load and save accelerator maps (it's now possible to edit the
    keyboard shortcuts)
  + Change the application icons
  + Add Ctrl+E shortcut for \emph{}
  + Improvements to the completion
  + Misc bugfixes
  + Translations updates
- Fix gtkspell buildrequires, Factory and above require gtkspell3
  instead of gtkspell now
- Now requires gtk+-3.0 >= 3.6.0 and gtksourceview >= 3.8.0 for
  building
- Add patch
  latexila-replace-deprecated-gtk_widget_render_icon.patch to
  replace deprecated gtk_widget_render_icon by
  gtk_widget_render_icon_pixbuf; fixes build failure due to
  "64bit portability issues".
* Thu Feb 28 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Thu Oct 25 2012 badshah400@gmail.com
- Update to version 2.6.1:
  + Autotools: required version of Vala is now optional
  + Comment selected lines: comment empty lines too
  + Misc bug fixes
- Changes from versions 2.6.0, 2.5.2, 2.5.3, 2.5.4:
  + See installed NEWS file for list of changes
- Modify spec file to adapt to (upstream) change of build from
  previously cmake based procedure to autotools based procedure
- Use upstream provided desktop file.
* Wed Oct 24 2012 p.drouand@gmail.com
- Fix build
* Mon Jun 25 2012 badshah400@gmail.com
- Update to version 2.5.1:
  + Figure insertion: swap \label and \caption
  + Use GResource for icons and symbols
  + Code refactoring for the symbols (in the side panel)
  + Fixes and improvements of the compilation with CMake
  + Updated Brazilian Portuguese, Czech, Serbian and Latvian
    translations
- Changes from version 2.5.0:
  + Port to GTK+ 3
  + Migrate from libunique to GtkApplication
  + Updated Spanish, Slovenian and French translations
* Thu Jun  7 2012 badshah400@gmail.com
- Update to version 2.4.1:
  + Figure insertion: swap \label and \caption
  + Updated French, Czech translations
  + Added Indonesian translation
- Changes from version 2.4.0:
  + Document compilation: set temporary location if file not saved
  + More documentation
  + Structure: bug fix for the display of simple lists
  + Build View: remove button "show critical errors"
  + Templates: code clean-up
  + More LaTeX commands for the completion
  + F12 shortcut to show/hide the side panel
  + TODO file removed (now in the wiki)
  + Updated Spanish, Slovenian, Serbian, French, German, Latvian,
    Norwegian bokmål and Czech translations
- Changes from version 2.3.1:
  + More completion data
  + Support drag and drop of a list of files
  + Completion: code clean-up
  + Beamer environments: frame, block, columns, column
    (in the LaTeX menu and in the edit toolbar)
  + Fix bug for structure actions 'delete' and 'cut'
  + Add Simplified Chinese, Norwegian bokmål translations
  + Updated Spanish translation
- Use upstream tarball (.tar.xz) for source.
* Fri Dec 16 2011 badshah400@gmail.com
- Prepare for submission to factory:
  + Remove sources for version 2.1.1
  + Package no longer builds for openSUSE < 12.1
  + Remove 0%%{?suse_version} > 1140 conditionals since package no
    longer builds for these versions anyway.
* Mon Dec 12 2011 badshah400@gmail.com
- Update to version 2.3.0:
  + Spell checking with GtkSpell
  + Build Tools: add XeTeX -> PDF with Latexmk
  + Improve figure environment insertion
  + Templates: better icons
  + Added Esperanto translation
  + Updated Swedish, French and German translations
  + New CMake option: VALAC
  + Switch to Vala 0.14
- Too many updates since version 2.0.8 from previous build, see
  /usr/share/doc/packages/latexila/NEWS for the complete list.
- Fix build failures on openSUSE > 11.4
- Versions 2.2.0 and above introduce a build dependency on itstool
  which is not available for openSUSE <= 11.4; use version 2.1.1
  as the highest that can build with openSUSE 11.4 and older.
* Wed Jun 22 2011 malcolmlewis@opensuse.org
- Initial build
